@@ -5,12 +5,9 @@
 #  Distributed under the MIT License.
 #  See LICENSE for more info.
 
-from datetime import datetime
-from qtpy.QtWidgets import QFileDialog
 from qtpy.QtWidgets import QAction
 
 from .iconcollection import IconCollection
-from .cameradialog import CameraDialog
 
 
 class ActionCollection:
@@ -171,53 +168,3 @@ class ActionCollection:
         self.action_take_screenshot = QAction('&Take screenshot', parent)
         self.action_take_screenshot.setIcon(IconCollection.get('webcam.svg'))
         self.action_take_screenshot.setShortcut('Ctrl+Shift+S')
-
-    """
-    Basic handlers
-    """
-    def connect_tree(self, tree) -> None:
-        self.action_show_tree.triggered.connect(tree.show)
-
-    def connect_main_widget(self, widget) -> None:
-        self.action_quit.triggered.connect(widget.close)
-
-    def connect_viewer(self, viewer) -> None:
-        self.action_plan_view.triggered.connect(viewer.plan_view)
-        self.action_north_view.triggered.connect(viewer.north_view)
-        self.action_east_view.triggered.connect(viewer.east_view)
-        self.action_fit_to_screen.triggered.connect(viewer.fit_to_screen)
-
-        self.action_autofit_to_screen.triggered.connect(viewer.set_autofit_status)
-        self.action_turbo_rendering.triggered.connect(viewer.set_turbo_status)
-
-        self.action_camera_properties.triggered.connect(lambda: ActionCollection.handle_camera(viewer))
-        self.action_take_screenshot.triggered.connect(lambda: ActionCollection.handle_screenshot(viewer))
-
-        viewer.signal_load_success.connect(viewer.update_turbo)
-        viewer.signal_load_success.connect(viewer.update_autofit)
-
-    """
-    Advanced handlers
-    """
-    @staticmethod
-    def handle_camera(viewer) -> None:
-        dialog = CameraDialog(viewer)
-        dialog.accepted.connect(lambda: ActionCollection.update_viewer(viewer, dialog))
-        dialog.show()
-
-    @staticmethod
-    def update_viewer(viewer, dialog: CameraDialog) -> None:
-        viewer.camera_position = dialog.camera_position
-        viewer.rotation_angle = dialog.rotation_angle
-        viewer.rotation_center = dialog.rotation_center
-        viewer.update()
-
-    @staticmethod
-    def handle_screenshot(viewer) -> None:
-        (path, selected_filter) = QFileDialog.getSaveFileName(
-            parent=viewer,
-            directory=f'BlastSight Screenshot ({datetime.now().strftime("%Y%m%d-%H%M%S")})',
-            filter='PNG image (*.png);;')
-
-        if path != '':
-            viewer.take_screenshot(path)
