@@ -10,10 +10,10 @@ from qtpy.QtWidgets import QColorDialog
 
 
 class ColorDialog(QColorDialog):
-    def __init__(self, parent=None, element=None):
+    def __init__(self, element, parent=None):
         QColorDialog.__init__(self, parent)
         self.setOption(self.ShowAlphaChannel)
         self.setOption(self.DontUseNativeDialog)
 
         self.setWindowTitle(f'{self.windowTitle()} ({element.name}.{element.extension})')
-        self.setCurrentColor(QColor.fromRgb(*[int(255 * x) for x in element.rgba.tolist()]))
+        self.setCurrentColor(QColor.fromRgbF(*element.rgba))
