@@ -37,7 +37,7 @@ class TreeWidget(QTreeWidget):
     signal_export_lines = Signal(int)
     signal_export_tubes = Signal(int)
 
-    def __init__(self, parent=None, viewer=None):
+    def __init__(self, viewer=None, parent=None):
         super().__init__(parent)
         self.setContextMenuPolicy(Qt.CustomContextMenu)
         self.setWindowFlags(Qt.WindowStaysOnTopHint)
@@ -49,11 +49,15 @@ class TreeWidget(QTreeWidget):
         self.setWindowTitle('Element list')
         self.headerItem().setText(0, 'Elements')
 
-        self.viewer = viewer
         self.is_export_enabled = False
-
-    def connect_viewer(self, viewer) -> None:
         self.viewer = viewer
+
+    def connect_viewer(self, viewer=None) -> None:
+        if bool(viewer):
+            self.viewer = viewer
+        if not bool(self.viewer):
+            return
+
         self.viewer.signal_file_modified.connect(self.auto_refill)
         self.viewer.signal_mesh_clicked.connect(self.handle_mesh_clicked)
         self.signal_colors_triggered.connect(self.handle_color)
@@ -64,17 +68,18 @@ class TreeWidget(QTreeWidget):
 
     def handle_color(self, _id: int) -> None:
         element = self.viewer.get_drawable(_id)
-        dialog = ColorDialog(self.viewer, element)
-        dialog.accepted.connect(lambda: self.update_color(dialog, element))
-        dialog.show()
+        dialog = ColorDialog(element)
 
-    def update_color(self, dialog, element) -> None:
-        element.rgba = [x / 255 for x in dialog.currentColor().getRgb()]
-        self.viewer.update_drawable(element.id)
+        def update_color() -> None:
+            element.rgba = dialog.currentColor().getRgbF()
+            self.viewer.update_drawable(element.id)
+
+        dialog.accepted.connect(update_color)
+        dialog.show()
 
     def handle_properties(self, _id: int) -> None:
         element = self.viewer.get_drawable(_id)
-        dialog = PropertiesDialog(self.viewer, element)
+        dialog = PropertiesDialog(element)
         dialog.accepted.connect(lambda: self.update_properties(dialog, element))
         dialog.show()
 
@@ -110,8 +115,14 @@ class TreeWidget(QTreeWidget):
     def auto_refill(self) -> None:
         self.clear()
 
-        for drawable in self.viewer.get_all_drawables():
-            self.addTopLevelItem(TreeWidgetItem(self, drawable))
+        for drawable in self.available_drawables():
+            self.addTopLevelItem(self.generate_item(drawable))
+
+    def available_drawables(self) -> list:
+        return self.viewer.get_all_drawables()
+
+    def generate_item(self, drawable) -> TreeWidgetItem:
+        return TreeWidgetItem(self, drawable)
 
     def context_menu(self, event) -> None:
         # Pop-up the context menu on current position, if an item is there
